==> kmymoney_4.6.6.orig.tar.xz: kmymoney-4.6.6/kmymoney/dialogs/settings/ksettingshome.h <==
/***************************************************************************
                          ksettingshome.h
                             -------------------
    copyright            : (C) 2005 by Thomas Baumgart
    email                : ipwizard@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSETTINGSHOME_H
#define KSETTINGSHOME_H

// ----------------------------------------------------------------------------
// QT Includes

// ----------------------------------------------------------------------------
// KDE Includes

// ----------------------------------------------------------------------------
// Project Includes

#include "ui_ksettingshomedecl.h"

class KSettingsHomeDecl : public QWidget, public Ui::KSettingsHomeDecl
{
public:
  KSettingsHomeDecl(QWidget *parent) : QWidget(parent) {
    setupUi(this);
  }
};


class KSettingsHome : public KSettingsHomeDecl
{
  Q_OBJECT

public:
  KSettingsHome(QWidget* parent = 0);
  ~KSettingsHome();

protected slots:
  void slotLoadItems(void);
  void slotUpdateItemList(void);
  void slotSelectHomePageItem();
  void slotMoveUp(void);
  void slotMoveDown(void);

private:
  bool m_noNeedToUpdateList;
};
#endif

==> kmymoney_5.0.1.orig.tar.xz: kmymoney-5.0.1/kmymoney/dialogs/settings/ksettingshome.h <==
/***************************************************************************
                          ksettingshome.h
                             -------------------
    copyright            : (C) 2005 by Thomas Baumgart
    email                : ipwizard@users.sourceforge.net
                           (C) 2017 by Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSETTINGSHOME_H
#define KSETTINGSHOME_H

// ----------------------------------------------------------------------------
// QT Includes

#include <QWidget>

// ----------------------------------------------------------------------------
// KDE Includes

// ----------------------------------------------------------------------------
// Project Includes

class KSettingsHomePrivate;
class KSettingsHome : public QWidget
{
  Q_OBJECT
  Q_DISABLE_COPY(KSettingsHome)

public:
  explicit KSettingsHome(QWidget* parent = nullptr);
  ~KSettingsHome();

protected Q_SLOTS:
  void slotLoadItems();
  void slotUpdateItemList();
  void slotSelectHomePageItem();
  void slotMoveUp();
  void slotMoveDown();

private:
  KSettingsHomePrivate * const d_ptr;
  Q_DECLARE_PRIVATE(KSettingsHome)
};
#endif
